==> dcmtk-docs-3.6.9-3-x86_64.pkg.tar.zst: usr/share/doc/dcmtk/html/search/variables_18.js <==
var searchData=
[
  ['x509_0',['x509',['../classSiCertificate.html#a0f0643b4996f0a4a78ff3bb5a417f215',1,'SiCertificate']]],
  ['x509store_1',['x509store',['../classSiCertificateVerifier.html#a450aa2ab1e58c4ae983f15bdc0e3a4d7',1,'SiCertificateVerifier']]],
  ['x509untrusted_2',['x509untrusted',['../classSiCertificateVerifier.html#a61341a763dae1c8b6e7ed57b97421f5a',1,'SiCertificateVerifier']]],
  ['xcoord_3',['XCoord',['../classDSRGraphicData3DItem.html#a07ddec98beaeb9056be90c74ed637f45',1,'DSRGraphicData3DItem']]],
  ['xdsretrievalsequence_4',['XDSRetrievalSequence',['../classDRTReferencedPatientPhotoSequence_1_1Item.html#afe57e8a74224ffc7ffb5db74cdb29b80',1,'DRTReferencedPatientPhotoSequence::Item']]],
  ['xf_5facceptemptystudyseriesinstanceuid_5',['XF_acceptEmptyStudySeriesInstanceUID',['../classDSRTypes.html#ade41d238b0109ec61582cf0b90e0c9d3',1,'DSRTypes']]],
  ['xf_5faddcommentsforincludedtemplate_6',['XF_addCommentsForIncludedTemplate',['../classDSRTypes.html#a70fe9ad3eae4e64e068d80d73a4d844c',1,'DSRTypes']]],
  ['xf_5fadddocumenttype_7',['XF_addDocumentType',['../structDCMTypes.html#a412ed02cca3bb774569203790600df59',1,'DCMTypes']]],
  ['xf_5faddschemareference_8',['XF_addSchemaReference',['../classDSRTypes.html#ab097d98f5fbece750b408df910f07527',1,'DSRTypes']]],
  ['xf_5falwayswriteitemidentifier_9',['XF_alwaysWriteItemIdentifier',['../classDSRTypes.html#a1f303af82c0d347105f7595ad6feb1c3',1,'DSRTypes']]],
  ['xf_5fcodecomponentsasattribute_10',['XF_codeComponentsAsAttribute',['../classDSRTypes.html#a429614441f36c56eff2c33a0f2780aa7',1,'DSRTypes']]],
  ['xf_5fconvertnonascii_11',['XF_convertNonASCII',['../structDCMTypes.html#ae20bd819e4ffd7a856607c609bb07c49',1,'DCMTypes']]],
  ['xf_5fembeddocumenttype_12',['XF_embedDocumentType',['../structDCMTypes.html#a2b2b4f7286293e92914725f486656e2a',1,'DCMTypes']]],
  ['xf_5fencodebase64_13',['XF_encodeBase64',['../structDCMTypes.html#a7489b68f366776523ac5fad8193c2ef2',1,'DCMTypes']]],
  ['xf_5fencodeeverythingasattribute_14',['XF_encodeEverythingAsAttribute',['../classDSRTypes.html#a4e867bdb19acf8a8ac3ca943cdf13803',1,'DSRTypes']]],
  ['xf_5fomitdataelementname_15',['XF_omitDataElementName',['../structDCMTypes.html#a7fffc998cac5884da91b261de74e77d3',1,'DCMTypes']]],
  ['xf_5frelationshiptypeasattribute_16',['XF_relationshipTypeAsAttribute',['../classDSRTypes.html#a990ed0d9968539d6a48ec259db747c93',1,'DSRTypes']]],
  ['xf_5ftemplateelementenclosesitems_17',['XF_templateElementEnclosesItems',['../classDSRTypes.html#a4da638986dc912836bd11af4ad983e32',1,'DSRTypes']]],
  ['xf_5ftemplateidentifierasattribute_18',['XF_templateIdentifierAsAttribute',['../classDSRTypes.html#a04f99acb1147af2ea233e5a685733154',1,'DSRTypes']]],
  ['xf_5fusedcmsrnamespace_19',['XF_useDcmsrNamespace',['../classDSRTypes.html#a64b752fbc8ce726a974b5608a472c9e5',1,'DSRTypes']]],
  ['xf_5fusenativemodel_20',['XF_useNativeModel',['../structDCMTypes.html#ad32966596a7f5523f3d4a6a992ebb6c9',1,'DCMTypes']]],
  ['xf_5fusexmlnamespace_21',['XF_useXMLNamespace',['../structDCMTypes.html#a6c7de932d6d9b298a5d9e96171b25261',1,'DCMTypes']]],
  ['xf_5fvalidateschema_22',['XF_validateSchema',['../classDSRTypes.html#a53cc017006806fdb829d1dba586b6ae0',1,'DSRTypes']]],
  ['xf_5fvaluetypeasattribute_23',['XF_valueTypeAsAttribute',['../classDSRTypes.html#af2bc54005747e3cdd9b3558e7ff22fa2',1,'DSRTypes']]],
  ['xf_5fwritebinarydata_24',['XF_writeBinaryData',['../structDCMTypes.html#a6b0e0f0037b273a61c1c2871b1176f2c',1,'DCMTypes']]],
  ['xf_5fwriteemptytags_25',['XF_writeEmptyTags',['../classDSRTypes.html#aa1f7636428ed2b26a5048c8ce5578f49',1,'DSRTypes']]],
  ['xf_5fwritetemplateidentification_26',['XF_writeTemplateIdentification',['../classDSRTypes.html#a1c57e1357b8305879b00f72d00c755e5',1,'DSRTypes']]],
  ['xfer_27',['Xfer',['../classDcmMetaInfo.html#a10c1e18aadc7fe1007f41e0dc09f57ed',1,'DcmMetaInfo::Xfer'],['../classDcmPixelSequence.html#a7b4fe46b421be7906f6f78b5aa07f176',1,'DcmPixelSequence::Xfer'],['../classDiDocument.html#a26eea87429cb5320bc2bb10bda8ddb09',1,'DiDocument::Xfer']]],
  ['xferid_28',['xferID',['../classDcmXfer.html#ab119447f8e04812aee870127b2636c89',1,'DcmXfer']]],
  ['xfername_29',['xferName',['../classDcmXfer.html#a1d21c15857423ba19a3b71ed9e5b3cd2',1,'DcmXfer']]],
  ['xfersyn_30',['xferSyn',['../classDcmXfer.html#a31fa1001cce6f58fb11b9c507822b453',1,'DcmXfer']]],
  ['xfersyntaxes_5f_31',['xferSyntaxes_',['../classDcmAssociationConfiguration.html#ac5e5ce372538777c45360d8b11fc3481',1,'DcmAssociationConfiguration']]],
  ['xfersyntaxgroup_5f_32',['xferSyntaxGroup_',['../classDcmPresentationContextItem.html#a30e1ff8eb26dfba96fb67ca6745f905f',1,'DcmPresentationContextItem']]],
  ['xfervalidity_33',['xferValidity',['../classDcmXfer.html#a9e114429ed9c9aa0cdf2abc9f5300b7c',1,'DcmXfer']]],
  ['xrayimagereceptorangle_34',['XRayImageReceptorAngle',['../classDRTImageIOD.html#ade71246d3451c96fe940e6def08df9cc',1,'DRTImageIOD::XRayImageReceptorAngle'],['../classDRTPlannedVerificationImageSequence_1_1Item.html#aa815ffc2b9f97f62adcd0bf8ee58033a',1,'DRTPlannedVerificationImageSequence::Item::XRayImageReceptorAngle']]],
  ['xrayimagereceptortranslation_35',['XRayImageReceptorTranslation',['../classDRTImageIOD.html#a7ce38bd6109f351fa7375193cc28c16e',1,'DRTImageIOD']]],
  ['xraytubecurrent_36',['XRayTubeCurrent',['../classDRTExposureSequence_1_1Item.html#aeca29fc2764eb558c12062b54e374fd7',1,'DRTExposureSequence::Item']]],
  ['xraytubecurrentinma_37',['XRayTubeCurrentInmA',['../classDRTExposureSequence_1_1Item.html#ab9297ebef82deafe4dcf4f869cb36b51',1,'DRTExposureSequence::Item']]],
  ['xtag_38',['XTag',['../structDB__SmallDcmElmt.html#a65ecee5fb1114aec51c08d0b97c29b76',1,'DB_SmallDcmElmt']]]
];

==> dcmtk-docs-3.7.0-1-x86_64.pkg.tar.zst: usr/share/doc/dcmtk/html/search/variables_18.js <==
var searchData=
[
  ['x509_0',['x509',['../classSiCertificate.html#a0f0643b4996f0a4a78ff3bb5a417f215',1,'SiCertificate']]],
  ['x509store_1',['x509store',['../classSiCertificateVerifier.html#a450aa2ab1e58c4ae983f15bdc0e3a4d7',1,'SiCertificateVerifier']]],
  ['x509untrusted_2',['x509untrusted',['../classSiCertificateVerifier.html#a61341a763dae1c8b6e7ed57b97421f5a',1,'SiCertificateVerifier']]],
  ['xcoord_3',['XCoord',['../classDSRGraphicData3DItem.html#a07ddec98beaeb9056be90c74ed637f45',1,'DSRGraphicData3DItem']]],
  ['xdsretrievalsequence_4',['XDSRetrievalSequence',['../classDRTReferencedPatientPhotoSequence_1_1Item.html#afe57e8a74224ffc7ffb5db74cdb29b80',1,'DRTReferencedPatientPhotoSequence::Item']]],
  ['xf_5facceptemptystudyseriesinstanceuid_5',['XF_acceptEmptyStudySeriesInstanceUID',['../classDSRTypes.html#ade41d238b0109ec61582cf0b90e0c9d3',1,'DSRTypes']]],
  ['xf_5faddcommentsforincludedtemplate_6',['XF_addCommentsForIncludedTemplate',['../classDSRTypes.html#a70fe9ad3eae4e64e068d80d73a4d844c',1,'DSRTypes']]],
  ['xf_5fadddocumenttype_7',['XF_addDocumentType',['../structDCMTypes.html#a412ed02cca3bb774569203790600df59',1,'DCMTypes']]],
  ['xf_5faddschemareference_8',['XF_addSchemaReference',['../classDSRTypes.html#ab097d98f5fbece750b408df910f07527',1,'DSRTypes']]],
  ['xf_5falwayswriteitemidentifier_9',['XF_alwaysWriteItemIdentifier',['../classDSRTypes.html#a1f303af82c0d347105f7595ad6feb1c3',1,'DSRTypes']]],
  ['xf_5fcodecomponentsasattribute_10',['XF_codeComponentsAsAttribute',['../classDSRTypes.html#a429614441f36c56eff2c33a0f2780aa7',1,'DSRTypes']]],
  ['xf_5fconvertnonascii_11',['XF_convertNonASCII',['../structDCMTypes.html#ae20bd819e4ffd7a856607c609bb07c49',1,'DCMTypes']]],
  ['xf_5fembeddocumenttype_12',['XF_embedDocumentType',['../structDCMTypes.html#a2b2b4f7286293e92914725f486656e2a',1,'DCMTypes']]],
  ['xf_5fencodebase64_13',['XF_encodeBase64',['../structDCMTypes.html#a7489b68f366776523ac5fad8193c2ef2',1,'DCMTypes']]],
  ['xf_5fencodeeverythingasattribute_14',['XF_encodeEverythingAsAttribute',['../classDSRTypes.html#a4e867bdb19acf8a8ac3ca943cdf13803',1,'DSRTypes']]],
  ['xf_5fomitdataelementname_15',['XF_omitDataElementName',['../structDCMTypes.html#a7fffc998cac5884da91b261de74e77d3',1,'DCMTypes']]],
  ['xf_5frelationshiptypeasattribute_16',['XF_relationshipTypeAsAttribute',['../classDSRTypes.html#a990ed0d9968539d6a48ec259db747c93',1,'DSRTypes']]],
  ['xf_5ftemplateelementenclosesitems_17',['XF_templateElementEnclosesItems',['../classDSRTypes.html#a4da638986dc912836bd11af4ad983e32',1,'DSRTypes']]],
  ['xf_5ftemplateidentifierasattribute_18',['XF_templateIdentifierAsAttribute',['../classDSRTypes.html#a04f99acb1147af2ea233e5a685733154',1,'DSRTypes']]],
  ['xf_5fusedcmsrnamespace_19',['XF_useDcmsrNamespace',['../classDSRTypes.html#a64b752fbc8ce726a974b5608a472c9e5',1,'DSRTypes']]],
  ['xf_5fusenativemodel_20',['XF_useNativeModel',['../structDCMTypes.html#ad32966596a7f5523f3d4a6a992ebb6c9',1,'DCMTypes']]],
  ['xf_5fusexmlnamespace_21',['XF_useXMLNamespace',['../structDCMTypes.html#a6c7de932d6d9b298a5d9e96171b25261',1,'DCMTypes']]],
  ['xf_5fvalidateschema_22',['XF_validateSchema',['../classDSRTypes.html#a53cc017006806fdb829d1dba586b6ae0',1,'DSRTypes']]],
  ['xf_5fvaluetypeasattribute_23',['XF_valueTypeAsAttribute',['../classDSRTypes.html#af2bc54005747e3cdd9b3558e7ff22fa2',1,'DSRTypes']]],
  ['xf_5fwritebinarydata_24',['XF_writeBinaryData',['../structDCMTypes.html#a6b0e0f0037b273a61c1c2871b1176f2c',1,'DCMTypes']]],
  ['xf_5fwriteemptytags_25',['XF_writeEmptyTags',['../classDSRTypes.html#aa1f7636428ed2b26a5048c8ce5578f49',1,'DSRTypes']]],
  ['xf_5fwritetemplateidentification_26',['XF_writeTemplateIdentification',['../classDSRTypes.html#a1c57e1357b8305879b00f72d00c755e5',1,'DSRTypes']]],
  ['xfer_27',['Xfer',['../classDcmMetaInfo.html#a10c1e18aadc7fe1007f41e0dc09f57ed',1,'DcmMetaInfo::Xfer'],['../classDcmPixelSequence.html#a7b4fe46b421be7906f6f78b5aa07f176',1,'DcmPixelSequence::Xfer'],['../classDiDocument.html#a26eea87429cb5320bc2bb10bda8ddb09',1,'DiDocument::Xfer']]],
  ['xferid_28',['xferID',['../classDcmXfer.html#ab119447f8e04812aee870127b2636c89',1,'DcmXfer']]],
  ['xfername_29',['xferName',['../classDcmXfer.html#a1d21c15857423ba19a3b71ed9e5b3cd2',1,'DcmXfer']]],
  ['xfersyn_30',['xferSyn',['../classDcmXfer.html#a31fa1001cce6f58fb11b9c507822b453',1,'DcmXfer']]],
  ['xfersyntax_5f_31',['xferSyntax_',['../classDcmJSONReader.html#aa4ae3e7b9780c9e0152bf9a6268465d4',1,'DcmJSONReader']]],
  ['xfersyntaxes_5f_32',['xferSyntaxes_',['../classDcmAssociationConfiguration.html#ac5e5ce372538777c45360d8b11fc3481',1,'DcmAssociationConfiguration']]],
  ['xfersyntaxgroup_5f_33',['xferSyntaxGroup_',['../classDcmPresentationContextItem.html#a30e1ff8eb26dfba96fb67ca6745f905f',1,'DcmPresentationContextItem']]],
  ['xfervalidity_34',['xferValidity',['../classDcmXfer.html#a9e114429ed9c9aa0cdf2abc9f5300b7c',1,'DcmXfer']]],
  ['xrayimagereceptorangle_35',['XRayImageReceptorAngle',['../classDRTImageIOD.html#ade71246d3451c96fe940e6def08df9cc',1,'DRTImageIOD::XRayImageReceptorAngle'],['../classDRTPlannedVerificationImageSequence_1_1Item.html#aa815ffc2b9f97f62adcd0bf8ee58033a',1,'DRTPlannedVerificationImageSequence::Item::XRayImageReceptorAngle']]],
  ['xrayimagereceptortranslation_36',['XRayImageReceptorTranslation',['../classDRTImageIOD.html#a7ce38bd6109f351fa7375193cc28c16e',1,'DRTImageIOD']]],
  ['xraytubecurrent_37',['XRayTubeCurrent',['../classDRTExposureSequence_1_1Item.html#aeca29fc2764eb558c12062b54e374fd7',1,'DRTExposureSequence::Item']]],
  ['xraytubecurrentinma_38',['XRayTubeCurrentInmA',['../classDRTExposureSequence_1_1Item.html#ab9297ebef82deafe4dcf4f869cb36b51',1,'DRTExposureSequence::Item']]],
  ['xtag_39',['XTag',['../structDB__SmallDcmElmt.html#a65ecee5fb1114aec51c08d0b97c29b76',1,'DB_SmallDcmElmt']]]
];
